/* DC9 update
 Esto es requerido por Dynamic C versin 9, para utilizar
una IP fija en programa y la interfaz Ethernet por defecto.
No es necesario en DC8, se autodefinen en las libs */
#define TCPCONFIG 0
#define USE_ETHERNET		1
/* Fin DC9 update */

/* TCP/IP stuff */

#define MY_IP_ADDRESS   "192.168.1.52"
#define MY_NETMASK      "255.255.255.0"

#define MY_GATEWAY		"192.168.1.1" 		// only needed if out of local LAN


#memmap xmem
#use "dcrtcp.lib"
#use "http.lib"


/* use flash import facility */

#ximport "bb.shtml"      index_html
#ximport "ok.html"      ok_html
#ximport "rabbit1.gif"    rabbit1_gif


/* the default for / must be first */
const static HttpType http_types[] =
{
   { ".shtml", "text/html", shtml_handler}, // ssi
   { ".html", "text/html", NULL},           // html
   { ".cgi", "", NULL},                     // cgi
   { ".gif", "image/gif", NULL}
};

int msg;								// count number of messages
char date[11],time[9];			// store current date&time

int submit(HttpState*);

const static HttpSpec http_flashspec[] =
{
   { HTTPSPEC_FILE,  "/",              index_html,    NULL, 0, NULL, NULL},
   { HTTPSPEC_FILE,  "/index.shtml",   index_html,    NULL, 0, NULL, NULL},
   { HTTPSPEC_FILE,  "/ok.html",   		ok_html,		   NULL, 0, NULL, NULL},
   { HTTPSPEC_FILE,  "/rabbit1.gif",   rabbit1_gif,   NULL, 0, NULL, NULL},

   { HTTPSPEC_VARIABLE, "msg",  0,    &msg, INT16,   "%d", NULL},
   { HTTPSPEC_VARIABLE, "date", 0,    date, PTR16,   "%s", NULL},
   { HTTPSPEC_VARIABLE, "time", 0,    time, PTR16,   "%s", NULL},

   { HTTPSPEC_FUNCTION,	"/submit.cgi",		 0,  submit, 0, NULL, NULL}
};

#define REDIRECTHOST		MY_IP_ADDRESS
#define REDIRECTTO      "http://" REDIRECTHOST "/ok.html"


/*	Hardware definitions for Powertip 320x240 FRS LCD displays on RCM2100

		PA.0-7	I/O	LCD D0-7

		PE.4	Out	LCD RD_
		PE.0	Out	LCD A0
		PE.3	Out	LCD WR_

		PE.1	Out	LCD CS_

*/

/* LCD control signals */
#define	LCD_RD	4
#define	LCD_A0	0
#define	LCD_WR	3
#define	LCD_CS	1


void MsDelay ( int iDelay )
{
	unsigned long ul0;
	ul0 = MS_TIMER;		// get current timer value
	while ( MS_TIMER < ul0 + (unsigned long) iDelay );
}


/* Low level functions */

#asm
;function requires one parameter:
;@sp+2= data to write
;
LCD_Write::
	ld hl,(sp+2)			; get data value (LSB)
	ld a,l
	ioi ld (PADR),a		; and write it (no shadow, no one else uses port A)
	ld hl,PEDRShadow		; point to control port (shadow)
	ld de,PEDR				; point to control port
	res LCD_WR,(HL)		; Lower WR
	ioi ldd					; do it
	ld hl,PEDRShadow		; point to control port (shadow)
	ld de,PEDR				; point to control port
	set LCD_WR,(HL)		; Rise WR
	ioi ldd					; do it
	ret

#endasm


void LCD_WriteCmd(unsigned char cmd)
{
	BitWrPortI ( PEDR, &PEDRShadow, 1,LCD_A0 );	// Rise A0 (Cmd)
	LCD_Write(cmd);
	BitWrPortI ( PEDR, &PEDRShadow, 0,LCD_A0 );	// Lower A0 (Data)
}

void LCD_WriteStrCmd(unsigned char *cmd,int len)
{
	LCD_WriteCmd(*cmd++);
	while(len--) {
		LCD_Write(*cmd++);
	}
}

unsigned char LCD_ReadData()
{
unsigned char data;
	WrPortI ( SPCR, &SPCRShadow, 0x80 );			// PA0-7 = Inputs, remove data from bus
	BitWrPortI ( PEDR, &PEDRShadow, 1,LCD_A0 );	// Rise A0 (Data)
	BitWrPortI ( PEDR, &PEDRShadow, 0,LCD_RD );	// Lower RD
	data=RdPortI(PADR);									// read data
	BitWrPortI ( PEDR, &PEDRShadow, 1,LCD_RD );	// Rise RD
	BitWrPortI ( PEDR, &PEDRShadow, 0,LCD_A0 );	// Lower A0 (Sts)
	WrPortI ( SPCR, &SPCRShadow, 0x84 );			// PA0-7 = Outputs
	return(data);
}



void LCD_init ()
{
const static unsigned char init_string1[]={
0x40,				// INIT
'\B00110001',	// extern CGROM (use RAM @F000), 8 pixel chars, no top-screen corr, LCD, normal
0x87,0x7,		// 8x8 characters
39,59,			// 320 pixels, 8 pixel characters => 40 characters per line (43)
239,				// 240 lines (30 txt lines)
40,0				// virtual screen = display screen
};

const static unsigned char init_string2[]={
0x44,				// SCROLL
0, 				// SAD1L: start address screen 1 (0x0000)
0, 				// SAD1H: (for text screen)
239, 				// SL1  : number of scrolling lines screen 1 (239 dec.)
0xB0, 			// SAD2L: start address screen 2 (1200=0x4b0)
0x04, 			// SAD2H: (for the graphics screen)
239, 				// SL2  : number of scrolling lines screen 2
0, 				// SAD3L:
0, 				// SAD3H:
0, 				// SAD4L:
0	 				// SAD4H:
};

const static unsigned char init_string3[]={
0x5D,				// CSRFORM
0x04,				// CRX: set the horizontal size of the cursor (4 pixel)
0x86				// CRY: set the vertical size of the cursor (6 pixel) CM : set the cursor display mode to block cursor
};


const static unsigned char init_string4[]={
0x5A,				// HDOT_SCR (0x5a), Sets horizontal scroll position (scroll rate).
0					// 1 pixel scroll
};

const static unsigned char init_string5[]={
0x5B,				// OVLAY, Selects layered screen composition and screen text/graphics mode.
'\B00000001'	//MX0, MX1: set the text/graphics overlay mode to EXOR
//		Bit 2-3 : DM1, DM2: set the display mode of screen block 1 and 3
//		Bit 4   : OV: set two or three layer compsition in gfx-mode
//		Bit 5-7 :  0: not used (set to 0)
};

const static unsigned char init_string6[]={
0x59,				// send command DISP_ON (0x59)
'\B00010110'	// cursor flash rate = 2 Hz, SAD1/2 no flashing, SAD3 off
};

	WrPortI ( PEDR,&PEDRShadow,'\B00011010' );		// Make sure CS,RD,WR are HIGH
	WrPortI ( PEDDR,&PEDDRShadow,'\B10011011' );	// PE0,1,4,3,7 = output (make sure no one else is using PE: Ethernet)
	WrPortI ( SPCR, &SPCRShadow, 0x84 );			// PA0-7 = Outputs
	MsDelay ( 1000 );				// wait for LCD to reset itself

	BitWrPortI ( PEDR, &PEDRShadow, 0,LCD_CS );	// Lower CS

	LCD_WriteStrCmd ( init_string1,sizeof(init_string1) );
	LCD_WriteStrCmd ( init_string2,sizeof(init_string2) );
	LCD_WriteStrCmd ( init_string3,sizeof(init_string3) );
	LCD_WriteCmd ( 0x4C );		// CSRDIR_RIGHT, sets the direction of automatic cursor increment to right.
	LCD_WriteStrCmd ( init_string4,sizeof(init_string4) );
	LCD_WriteStrCmd ( init_string5,sizeof(init_string5) );
	LCD_WriteStrCmd ( init_string6,sizeof(init_string6) );
}

/* High level functions */

void LCD_cursor ( int address )
{
	LCD_WriteCmd(0x46);									// CSRW, Sets cursor address.
	LCD_Write(address&0xFF);							// LO byte
	LCD_Write((address>>8)&0xFF);						// HI byte
}

void LCD_fill(unsigned char pattern, int len)
{
int i;
	LCD_WriteCmd(0x42);									// MWRITE
	while(len--)
			LCD_Write(pattern);							// fill with pattern
}

void LCD_cleargfx ( void )
{
	LCD_cursor(1200);							// address gfx screen
	LCD_fill(0,9600);							// clear screen (fill 240 lines of 40 stripes with 0's)
}

void LCD_cleartxt ( void )
{
	LCD_cursor(0);								// address txt screen
	LCD_fill(' ',1200);						// clear screen (fill 30 lines with 40 spaces)
}

void LCD_printat (unsigned int row, unsigned int col, char *ptr)
{
	LCD_cursor (40*row+col);							// set cursor address
	LCD_WriteCmd(0x42);									// MWRITE
 	while (*ptr)
		LCD_Write (*ptr++);
}

void LCD_scroll()
{
int i,line;
unsigned char data[40];

	for(line=2;line<30;line++) {					// leave line 0 alone (datetime)
		LCD_cursor(40*line);							// address 1st char in current line
		LCD_WriteCmd(0x43);							// MREAD
		for(i=0;i<40;i++)
			data[i]=LCD_ReadData();					// get line data
		if(line==29){
			LCD_cursor(40*line);						// address 1st char in current line
			LCD_WriteCmd(0x42);						// MWRITE
			for(i=0;i<40;i++)
				LCD_Write(' ');						// clear last row
		}
		LCD_cursor(40*(line-1));					// address 1st char in upper line
		LCD_WriteCmd(0x42);							// MWRITE
			for(i=0;i<40;i++)
				LCD_Write(data[i]);					// move line up
	}
}

void LCD_loadfont()
{
xmem const static unsigned char fontdata[] = {		// define your own at will, 256 chars

   /* 0 0x00 '^@' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 1 0x01 '^A' */
   0x7e, /* 01111110 */
   0x81, /* 10000001 */
   0xa5, /* 10100101 */
   0x81, /* 10000001 */
   0xbd, /* 10111101 */
   0x99, /* 10011001 */
   0x81, /* 10000001 */
   0x7e, /* 01111110 */

   /* 2 0x02 '^B' */
   0x7e, /* 01111110 */
   0xff, /* 11111111 */
   0xdb, /* 11011011 */
   0xff, /* 11111111 */
   0xc3, /* 11000011 */
   0xe7, /* 11100111 */
   0xff, /* 11111111 */
   0x7e, /* 01111110 */

   /* 3 0x03 '^C' */
   0x6c, /* 01101100 */
   0xfe, /* 11111110 */
   0xfe, /* 11111110 */
   0xfe, /* 11111110 */
   0x7c, /* 01111100 */
   0x38, /* 00111000 */
   0x10, /* 00010000 */
   0x00, /* 00000000 */

   /* 4 0x04 '^D' */
   0x10, /* 00010000 */
   0x38, /* 00111000 */
   0x7c, /* 01111100 */
   0xfe, /* 11111110 */
   0x7c, /* 01111100 */
   0x38, /* 00111000 */
   0x10, /* 00010000 */
   0x00, /* 00000000 */

   /* 5 0x05 '^E' */
   0x38, /* 00111000 */
   0x7c, /* 01111100 */
   0x38, /* 00111000 */
   0xfe, /* 11111110 */
   0xfe, /* 11111110 */
   0xd6, /* 11010110 */
   0x10, /* 00010000 */
   0x38, /* 00111000 */

   /* 6 0x06 '^F' */
   0x10, /* 00010000 */
   0x38, /* 00111000 */
   0x7c, /* 01111100 */
   0xfe, /* 11111110 */
   0xfe, /* 11111110 */
   0x7c, /* 01111100 */
   0x10, /* 00010000 */
   0x38, /* 00111000 */

   /* 7 0x07 '^G' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x3c, /* 00111100 */
   0x3c, /* 00111100 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 8 0x08 '^H' */
   0xff, /* 11111111 */
   0xff, /* 11111111 */
   0xe7, /* 11100111 */
   0xc3, /* 11000011 */
   0xc3, /* 11000011 */
   0xe7, /* 11100111 */
   0xff, /* 11111111 */
   0xff, /* 11111111 */

   /* 9 0x09 '^I' */
   0x00, /* 00000000 */
   0x3c, /* 00111100 */
   0x66, /* 01100110 */
   0x42, /* 01000010 */
   0x42, /* 01000010 */
   0x66, /* 01100110 */
   0x3c, /* 00111100 */
   0x00, /* 00000000 */

   /* 10 0x0a '^J' */
   0xff, /* 11111111 */
   0xc3, /* 11000011 */
   0x99, /* 10011001 */
   0xbd, /* 10111101 */
   0xbd, /* 10111101 */
   0x99, /* 10011001 */
   0xc3, /* 11000011 */
   0xff, /* 11111111 */

   /* 11 0x0b '^K' */
   0x0f, /* 00001111 */
   0x07, /* 00000111 */
   0x0f, /* 00001111 */
   0x7d, /* 01111101 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0x78, /* 01111000 */

   /* 12 0x0c '^L' */
   0x3c, /* 00111100 */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x3c, /* 00111100 */
   0x18, /* 00011000 */
   0x7e, /* 01111110 */
   0x18, /* 00011000 */

   /* 13 0x0d '^M' */
   0x3f, /* 00111111 */
   0x33, /* 00110011 */
   0x3f, /* 00111111 */
   0x30, /* 00110000 */
   0x30, /* 00110000 */
   0x70, /* 01110000 */
   0xf0, /* 11110000 */
   0xe0, /* 11100000 */

   /* 14 0x0e '^N' */
   0x7f, /* 01111111 */
   0x63, /* 01100011 */
   0x7f, /* 01111111 */
   0x63, /* 01100011 */
   0x63, /* 01100011 */
   0x67, /* 01100111 */
   0xe6, /* 11100110 */
   0xc0, /* 11000000 */

   /* 15 0x0f '^O' */
   0x18, /* 00011000 */
   0xdb, /* 11011011 */
   0x3c, /* 00111100 */
   0xe7, /* 11100111 */
   0xe7, /* 11100111 */
   0x3c, /* 00111100 */
   0xdb, /* 11011011 */
   0x18, /* 00011000 */

   /* 16 0x10 '^P' */
   0x80, /* 10000000 */
   0xe0, /* 11100000 */
   0xf8, /* 11111000 */
   0xfe, /* 11111110 */
   0xf8, /* 11111000 */
   0xe0, /* 11100000 */
   0x80, /* 10000000 */
   0x00, /* 00000000 */

   /* 17 0x11 '^Q' */
   0x02, /* 00000010 */
   0x0e, /* 00001110 */
   0x3e, /* 00111110 */
   0xfe, /* 11111110 */
   0x3e, /* 00111110 */
   0x0e, /* 00001110 */
   0x02, /* 00000010 */
   0x00, /* 00000000 */

   /* 18 0x12 '^R' */
   0x18, /* 00011000 */
   0x3c, /* 00111100 */
   0x7e, /* 01111110 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x7e, /* 01111110 */
   0x3c, /* 00111100 */
   0x18, /* 00011000 */

   /* 19 0x13 '^S' */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x00, /* 00000000 */
   0x66, /* 01100110 */
   0x00, /* 00000000 */

   /* 20 0x14 '^T' */
   0x7f, /* 01111111 */
   0xdb, /* 11011011 */
   0xdb, /* 11011011 */
   0x7b, /* 01111011 */
   0x1b, /* 00011011 */
   0x1b, /* 00011011 */
   0x1b, /* 00011011 */
   0x00, /* 00000000 */

   /* 21 0x15 '^U' */
   0x3e, /* 00111110 */
   0x61, /* 01100001 */
   0x3c, /* 00111100 */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x3c, /* 00111100 */
   0x86, /* 10000110 */
   0x7c, /* 01111100 */

   /* 22 0x16 '^V' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0x7e, /* 01111110 */
   0x7e, /* 01111110 */
   0x00, /* 00000000 */

   /* 23 0x17 '^W' */
   0x18, /* 00011000 */
   0x3c, /* 00111100 */
   0x7e, /* 01111110 */
   0x18, /* 00011000 */
   0x7e, /* 01111110 */
   0x3c, /* 00111100 */
   0x18, /* 00011000 */
   0xff, /* 11111111 */

   /* 24 0x18 '^X' */
   0x18, /* 00011000 */
   0x3c, /* 00111100 */
   0x7e, /* 01111110 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 25 0x19 '^Y' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x7e, /* 01111110 */
   0x3c, /* 00111100 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 26 0x1a '^Z' */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x0c, /* 00001100 */
   0xfe, /* 11111110 */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 27 0x1b '^[' */
   0x00, /* 00000000 */
   0x30, /* 00110000 */
   0x60, /* 01100000 */
   0xfe, /* 11111110 */
   0x60, /* 01100000 */
   0x30, /* 00110000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 28 0x1c '^\' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xfe, /* 11111110 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 29 0x1d '^]' */
   0x00, /* 00000000 */
   0x24, /* 00100100 */
   0x66, /* 01100110 */
   0xff, /* 11111111 */
   0x66, /* 01100110 */
   0x24, /* 00100100 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 30 0x1e '^^' */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x3c, /* 00111100 */
   0x7e, /* 01111110 */
   0xff, /* 11111111 */
   0xff, /* 11111111 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 31 0x1f '^_' */
   0x00, /* 00000000 */
   0xff, /* 11111111 */
   0xff, /* 11111111 */
   0x7e, /* 01111110 */
   0x3c, /* 00111100 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 32 0x20 ' ' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 33 0x21 '!' */
   0x18, /* 00011000 */
   0x3c, /* 00111100 */
   0x3c, /* 00111100 */
   0x3c, /* 00111100 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 34 0x22 '"' */
   0x6c, /* 01101100 */
   0x6c, /* 01101100 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 35 0x23 '#' */
   0x6c, /* 01101100 */
   0x6c, /* 01101100 */
   0xfe, /* 11111110 */
   0x6c, /* 01101100 */
   0xfe, /* 11111110 */
   0x6c, /* 01101100 */
   0x6c, /* 01101100 */
   0x00, /* 00000000 */

   /* 36 0x24 '$' */
   0x18, /* 00011000 */
   0x3e, /* 00111110 */
   0x60, /* 01100000 */
   0x3c, /* 00111100 */
   0x06, /* 00000110 */
   0x7c, /* 01111100 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 37 0x25 '%' */
   0x00, /* 00000000 */
   0xc6, /* 11000110 */
   0xcc, /* 11001100 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x66, /* 01100110 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 38 0x26 '&' */
   0x38, /* 00111000 */
   0x6c, /* 01101100 */
   0x68, /* 01101000 */
   0x76, /* 01110110 */
   0xdc, /* 11011100 */
   0xcc, /* 11001100 */
   0x76, /* 01110110 */
   0x00, /* 00000000 */

   /* 39 0x27 ''' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 40 0x28 '(' */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x30, /* 00110000 */
   0x30, /* 00110000 */
   0x18, /* 00011000 */
   0x0c, /* 00001100 */
   0x00, /* 00000000 */

   /* 41 0x29 ')' */
   0x30, /* 00110000 */
   0x18, /* 00011000 */
   0x0c, /* 00001100 */
   0x0c, /* 00001100 */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x00, /* 00000000 */

   /* 42 0x2a '*' */
   0x00, /* 00000000 */
   0x66, /* 01100110 */
   0x3c, /* 00111100 */
   0xff, /* 11111111 */
   0x3c, /* 00111100 */
   0x66, /* 01100110 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 43 0x2b '+' */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x7e, /* 01111110 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 44 0x2c ',' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */

   /* 45 0x2d '-' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 46 0x2e '.' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 47 0x2f '/' */
   0x03, /* 00000011 */
   0x06, /* 00000110 */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x60, /* 01100000 */
   0xc0, /* 11000000 */
   0x00, /* 00000000 */

   /* 48 0x30 '0' */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xde, /* 11011110 */
   0xfe, /* 11111110 */
   0xf6, /* 11110110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 49 0x31 '1' */
   0x18, /* 00011000 */
   0x78, /* 01111000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 50 0x32 '2' */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x60, /* 01100000 */
   0xfe, /* 11111110 */
   0x00, /* 00000000 */

   /* 51 0x33 '3' */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0x06, /* 00000110 */
   0x1c, /* 00011100 */
   0x06, /* 00000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 52 0x34 '4' */
   0x1c, /* 00011100 */
   0x3c, /* 00111100 */
   0x6c, /* 01101100 */
   0xcc, /* 11001100 */
   0xfe, /* 11111110 */
   0x0c, /* 00001100 */
   0x0c, /* 00001100 */
   0x00, /* 00000000 */

   /* 53 0x35 '5' */
   0xfe, /* 11111110 */
   0xc0, /* 11000000 */
   0xfc, /* 11111100 */
   0x06, /* 00000110 */
   0x06, /* 00000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 54 0x36 '6' */
   0x38, /* 00111000 */
   0x60, /* 01100000 */
   0xc0, /* 11000000 */
   0xfc, /* 11111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 55 0x37 '7' */
   0xfe, /* 11111110 */
   0x06, /* 00000110 */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x60, /* 01100000 */
   0x60, /* 01100000 */
   0x00, /* 00000000 */

   /* 56 0x38 '8' */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 57 0x39 '9' */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7e, /* 01111110 */
   0x06, /* 00000110 */
   0x0c, /* 00001100 */
   0x38, /* 00111000 */
   0x00, /* 00000000 */

   /* 58 0x3a ':' */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 59 0x3b ';' */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */

   /* 60 0x3c '<' */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x60, /* 01100000 */
   0x30, /* 00110000 */
   0x18, /* 00011000 */
   0x0c, /* 00001100 */
   0x00, /* 00000000 */

   /* 61 0x3d '=' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 62 0x3e '>' */
   0x30, /* 00110000 */
   0x18, /* 00011000 */
   0x0c, /* 00001100 */
   0x06, /* 00000110 */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x00, /* 00000000 */

   /* 63 0x3f '?' */
   0x3c, /* 00111100 */
   0x66, /* 01100110 */
   0x06, /* 00000110 */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 64 0x40 '@' */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xde, /* 11011110 */
   0xde, /* 11011110 */
   0xde, /* 11011110 */
   0xc0, /* 11000000 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 65 0x41 'A' */
   0x10, /* 00010000 */
   0x38, /* 00111000 */
   0x6c, /* 01101100 */
   0xc6, /* 11000110 */
   0xfe, /* 11111110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 66 0x42 'B' */
   0xfc, /* 11111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xfc, /* 11111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xfc, /* 11111100 */
   0x00, /* 00000000 */

   /* 67 0x43 'C' */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 68 0x44 'D' */
   0xfc, /* 11111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xfc, /* 11111100 */
   0x00, /* 00000000 */

   /* 69 0x45 'E' */
   0xfe, /* 11111110 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xf8, /* 11111000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xfe, /* 11111110 */
   0x00, /* 00000000 */

   /* 70 0x46 'F' */
   0xfe, /* 11111110 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xf8, /* 11111000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0x00, /* 00000000 */

   /* 71 0x47 'G' */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc0, /* 11000000 */
   0xce, /* 11001110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 72 0x48 'H' */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xfe, /* 11111110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 73 0x49 'I' */
   0x7e, /* 01111110 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x7e, /* 01111110 */
   0x00, /* 00000000 */

   /* 74 0x4a 'J' */
   0x06, /* 00000110 */
   0x06, /* 00000110 */
   0x06, /* 00000110 */
   0x06, /* 00000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 75 0x4b 'K' */
   0xc6, /* 11000110 */
   0xcc, /* 11001100 */
   0xd8, /* 11011000 */
   0xf0, /* 11110000 */
   0xd8, /* 11011000 */
   0xcc, /* 11001100 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 76 0x4c 'L' */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xfe, /* 11111110 */
   0x00, /* 00000000 */

   /* 77 0x4d 'M' */
   0x82, /* 10000010 */
   0xc6, /* 11000110 */
   0xee, /* 11101110 */
   0xfe, /* 11111110 */
   0xd6, /* 11010110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 78 0x4e 'N' */
   0xc6, /* 11000110 */
   0xe6, /* 11100110 */
   0xf6, /* 11110110 */
   0xde, /* 11011110 */
   0xce, /* 11001110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 79 0x4f 'O' */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 80 0x50 'P' */
   0xfc, /* 11111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xfc, /* 11111100 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0x00, /* 00000000 */

   /* 81 0x51 'Q' */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xf6, /* 11110110 */
   0xde, /* 11011110 */
   0x7c, /* 01111100 */
   0x06, /* 00000110 */

   /* 82 0x52 'R' */
   0xfc, /* 11111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xfc, /* 11111100 */
   0xd8, /* 11011000 */
   0xcc, /* 11001100 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 83 0x53 'S' */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0x60, /* 01100000 */
   0x38, /* 00111000 */
   0x0c, /* 00001100 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 84 0x54 'T' */
   0x7e, /* 01111110 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 85 0x55 'U' */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 86 0x56 'V' */
   0xc3, /* 11000011 */
   0xc3, /* 11000011 */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x3c, /* 00111100 */
   0x3c, /* 00111100 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 87 0x57 'W' */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xd6, /* 11010110 */
   0xfe, /* 11111110 */
   0xee, /* 11101110 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 88 0x58 'X' */
   0xc3, /* 11000011 */
   0x66, /* 01100110 */
   0x3c, /* 00111100 */
   0x18, /* 00011000 */
   0x3c, /* 00111100 */
   0x66, /* 01100110 */
   0xc3, /* 11000011 */
   0x00, /* 00000000 */

   /* 89 0x59 'Y' */
   0xc3, /* 11000011 */
   0xc3, /* 11000011 */
   0x66, /* 01100110 */
   0x3c, /* 00111100 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 90 0x5a 'Z' */
   0xfe, /* 11111110 */
   0x06, /* 00000110 */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x60, /* 01100000 */
   0xfe, /* 11111110 */
   0x00, /* 00000000 */

   /* 91 0x5b '[' */
   0x3c, /* 00111100 */
   0x30, /* 00110000 */
   0x30, /* 00110000 */
   0x30, /* 00110000 */
   0x30, /* 00110000 */
   0x30, /* 00110000 */
   0x3c, /* 00111100 */
   0x00, /* 00000000 */

   /* 92 0x5c '\' */
   0xc0, /* 11000000 */
   0x60, /* 01100000 */
   0x30, /* 00110000 */
   0x18, /* 00011000 */
   0x0c, /* 00001100 */
   0x06, /* 00000110 */
   0x03, /* 00000011 */
   0x00, /* 00000000 */

   /* 93 0x5d ']' */
   0x3c, /* 00111100 */
   0x0c, /* 00001100 */
   0x0c, /* 00001100 */
   0x0c, /* 00001100 */
   0x0c, /* 00001100 */
   0x0c, /* 00001100 */
   0x3c, /* 00111100 */
   0x00, /* 00000000 */

   /* 94 0x5e '^' */
   0x10, /* 00010000 */
   0x38, /* 00111000 */
   0x6c, /* 01101100 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 95 0x5f '_' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xfe, /* 11111110 */

   /* 96 0x60 '`' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x0c, /* 00001100 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 97 0x61 'a' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7c, /* 01111100 */
   0x06, /* 00000110 */
   0x7e, /* 01111110 */
   0xc6, /* 11000110 */
   0x7e, /* 01111110 */
   0x00, /* 00000000 */

   /* 98 0x62 'b' */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xfc, /* 11111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xfc, /* 11111100 */
   0x00, /* 00000000 */

   /* 99 0x63 'c' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc0, /* 11000000 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 100 0x64 'd' */
   0x06, /* 00000110 */
   0x06, /* 00000110 */
   0x7e, /* 01111110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7e, /* 01111110 */
   0x00, /* 00000000 */

   /* 101 0x65 'e' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xfe, /* 11111110 */
   0xc0, /* 11000000 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 102 0x66 'f' */
   0x3c, /* 00111100 */
   0x66, /* 01100110 */
   0x60, /* 01100000 */
   0xf0, /* 11110000 */
   0x60, /* 01100000 */
   0x60, /* 01100000 */
   0x60, /* 01100000 */
   0x00, /* 00000000 */

   /* 103 0x67 'g' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7e, /* 01111110 */
   0x06, /* 00000110 */
   0x7c, /* 01111100 */

   /* 104 0x68 'h' */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xfc, /* 11111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 105 0x69 'i' */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x38, /* 00111000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 106 0x6a 'j' */
   0x06, /* 00000110 */
   0x00, /* 00000000 */
   0x06, /* 00000110 */
   0x06, /* 00000110 */
   0x06, /* 00000110 */
   0x06, /* 00000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */

   /* 107 0x6b 'k' */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xcc, /* 11001100 */
   0xd8, /* 11011000 */
   0xf0, /* 11110000 */
   0xd8, /* 11011000 */
   0xcc, /* 11001100 */
   0x00, /* 00000000 */

   /* 108 0x6c 'l' */
   0x38, /* 00111000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 109 0x6d 'm' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xec, /* 11101100 */
   0xfe, /* 11111110 */
   0xd6, /* 11010110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 110 0x6e 'n' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xfc, /* 11111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 111 0x6f 'o' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 112 0x70 'p' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xfc, /* 11111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xfc, /* 11111100 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */

   /* 113 0x71 'q' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7e, /* 01111110 */
   0x06, /* 00000110 */
   0x06, /* 00000110 */

   /* 114 0x72 'r' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xdc, /* 11011100 */
   0xe6, /* 11100110 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0x00, /* 00000000 */

   /* 115 0x73 's' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0xc0, /* 11000000 */
   0x7c, /* 01111100 */
   0x06, /* 00000110 */
   0xfc, /* 11111100 */
   0x00, /* 00000000 */

   /* 116 0x74 't' */
   0x30, /* 00110000 */
   0x30, /* 00110000 */
   0x7c, /* 01111100 */
   0x30, /* 00110000 */
   0x30, /* 00110000 */
   0x36, /* 00110110 */
   0x1c, /* 00011100 */
   0x00, /* 00000000 */

   /* 117 0x75 'u' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 118 0x76 'v' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x6c, /* 01101100 */
   0x38, /* 00111000 */
   0x00, /* 00000000 */

   /* 119 0x77 'w' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xd6, /* 11010110 */
   0xfe, /* 11111110 */
   0x6c, /* 01101100 */
   0x00, /* 00000000 */

   /* 120 0x78 'x' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xc6, /* 11000110 */
   0x6c, /* 01101100 */
   0x38, /* 00111000 */
   0x6c, /* 01101100 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 121 0x79 'y' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xc3, /* 11000011 */
   0x66, /* 01100110 */
   0x3c, /* 00111100 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x60, /* 01100000 */

   /* 122 0x7a 'z' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xfe, /* 11111110 */
   0x0c, /* 00001100 */
   0x38, /* 00111000 */
   0x60, /* 01100000 */
   0xfe, /* 11111110 */
   0x00, /* 00000000 */

   /* 123 0x7b '{' */
   0x0e, /* 00001110 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x70, /* 01110000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x0e, /* 00001110 */
   0x00, /* 00000000 */

   /* 124 0x7c '|' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 125 0x7d '}' */
   0x70, /* 01110000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x0e, /* 00001110 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x70, /* 01110000 */
   0x00, /* 00000000 */

   /* 126 0x7e '~' */
   0x72, /* 01110010 */
   0x9c, /* 10011100 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 127 0x7f '' */
   0x00, /* 00000000 */
   0x10, /* 00010000 */
   0x38, /* 00111000 */
   0x6c, /* 01101100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xfe, /* 11111110 */
   0x00, /* 00000000 */

   /* 128 0x80 '' */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x0c, /* 00001100 */
   0x78, /* 01111000 */

   /* 129 0x81 '' */
   0xcc, /* 11001100 */
   0x00, /* 00000000 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0x76, /* 01110110 */
   0x00, /* 00000000 */

   /* 130 0x82 '' */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xfe, /* 11111110 */
   0xc0, /* 11000000 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 131 0x83 '' */
   0x7c, /* 01111100 */
   0x82, /* 10000010 */
   0x78, /* 01111000 */
   0x0c, /* 00001100 */
   0x7c, /* 01111100 */
   0xcc, /* 11001100 */
   0x76, /* 01110110 */
   0x00, /* 00000000 */

   /* 132 0x84 '' */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */
   0x78, /* 01111000 */
   0x0c, /* 00001100 */
   0x7c, /* 01111100 */
   0xcc, /* 11001100 */
   0x76, /* 01110110 */
   0x00, /* 00000000 */

   /* 133 0x85 '' */
   0x30, /* 00110000 */
   0x18, /* 00011000 */
   0x78, /* 01111000 */
   0x0c, /* 00001100 */
   0x7c, /* 01111100 */
   0xcc, /* 11001100 */
   0x76, /* 01110110 */
   0x00, /* 00000000 */

   /* 134 0x86 '' */
   0x30, /* 00110000 */
   0x30, /* 00110000 */
   0x78, /* 01111000 */
   0x0c, /* 00001100 */
   0x7c, /* 01111100 */
   0xcc, /* 11001100 */
   0x76, /* 01110110 */
   0x00, /* 00000000 */

   /* 135 0x87 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0x7e, /* 01111110 */
   0x0c, /* 00001100 */
   0x38, /* 00111000 */

   /* 136 0x88 '' */
   0x7c, /* 01111100 */
   0x82, /* 10000010 */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xfe, /* 11111110 */
   0xc0, /* 11000000 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 137 0x89 '' */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xfe, /* 11111110 */
   0xc0, /* 11000000 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 138 0x8a '' */
   0x30, /* 00110000 */
   0x18, /* 00011000 */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xfe, /* 11111110 */
   0xc0, /* 11000000 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 139 0x8b '' */
   0x66, /* 01100110 */
   0x00, /* 00000000 */
   0x38, /* 00111000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x3c, /* 00111100 */
   0x00, /* 00000000 */

   /* 140 0x8c '' */
   0x7c, /* 01111100 */
   0x82, /* 10000010 */
   0x38, /* 00111000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x3c, /* 00111100 */
   0x00, /* 00000000 */

   /* 141 0x8d '' */
   0x30, /* 00110000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x38, /* 00111000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x3c, /* 00111100 */
   0x00, /* 00000000 */

   /* 142 0x8e '' */
   0xc6, /* 11000110 */
   0x38, /* 00111000 */
   0x6c, /* 01101100 */
   0xc6, /* 11000110 */
   0xfe, /* 11111110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 143 0x8f '' */
   0x38, /* 00111000 */
   0x6c, /* 01101100 */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xfe, /* 11111110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 144 0x90 '' */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0xfe, /* 11111110 */
   0xc0, /* 11000000 */
   0xf8, /* 11111000 */
   0xc0, /* 11000000 */
   0xfe, /* 11111110 */
   0x00, /* 00000000 */

   /* 145 0x91 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0x18, /* 00011000 */
   0x7e, /* 01111110 */
   0xd8, /* 11011000 */
   0x7e, /* 01111110 */
   0x00, /* 00000000 */

   /* 146 0x92 '' */
   0x3e, /* 00111110 */
   0x6c, /* 01101100 */
   0xcc, /* 11001100 */
   0xfe, /* 11111110 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0xce, /* 11001110 */
   0x00, /* 00000000 */

   /* 147 0x93 '' */
   0x7c, /* 01111100 */
   0x82, /* 10000010 */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 148 0x94 '' */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 149 0x95 '' */
   0x30, /* 00110000 */
   0x18, /* 00011000 */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 150 0x96 '' */
   0x78, /* 01111000 */
   0x84, /* 10000100 */
   0x00, /* 00000000 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0x76, /* 01110110 */
   0x00, /* 00000000 */

   /* 151 0x97 '' */
   0x60, /* 01100000 */
   0x30, /* 00110000 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0x76, /* 01110110 */
   0x00, /* 00000000 */

   /* 152 0x98 '' */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7e, /* 01111110 */
   0x06, /* 00000110 */
   0xfc, /* 11111100 */

   /* 153 0x99 '' */
   0xc6, /* 11000110 */
   0x38, /* 00111000 */
   0x6c, /* 01101100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x6c, /* 01101100 */
   0x38, /* 00111000 */
   0x00, /* 00000000 */

   /* 154 0x9a '' */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 155 0x9b '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x7e, /* 01111110 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0x7e, /* 01111110 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 156 0x9c '' */
   0x38, /* 00111000 */
   0x6c, /* 01101100 */
   0x64, /* 01100100 */
   0xf0, /* 11110000 */
   0x60, /* 01100000 */
   0x66, /* 01100110 */
   0xfc, /* 11111100 */
   0x00, /* 00000000 */

   /* 157 0x9d '' */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x3c, /* 00111100 */
   0x7e, /* 01111110 */
   0x18, /* 00011000 */
   0x7e, /* 01111110 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 158 0x9e '' */
   0xf8, /* 11111000 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0xfa, /* 11111010 */
   0xc6, /* 11000110 */
   0xcf, /* 11001111 */
   0xc6, /* 11000110 */
   0xc7, /* 11000111 */

   /* 159 0x9f '' */
   0x0e, /* 00001110 */
   0x1b, /* 00011011 */
   0x18, /* 00011000 */
   0x3c, /* 00111100 */
   0x18, /* 00011000 */
   0xd8, /* 11011000 */
   0x70, /* 01110000 */
   0x00, /* 00000000 */

   /* 160 0xa0 '' */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x78, /* 01111000 */
   0x0c, /* 00001100 */
   0x7c, /* 01111100 */
   0xcc, /* 11001100 */
   0x76, /* 01110110 */
   0x00, /* 00000000 */

   /* 161 0xa1 '' */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x38, /* 00111000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x3c, /* 00111100 */
   0x00, /* 00000000 */

   /* 162 0xa2 '' */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */

   /* 163 0xa3 '' */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0x76, /* 01110110 */
   0x00, /* 00000000 */

   /* 164 0xa4 '' */
   0x76, /* 01110110 */
   0xdc, /* 11011100 */
   0x00, /* 00000000 */
   0xdc, /* 11011100 */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x00, /* 00000000 */

   /* 165 0xa5 '' */
   0x76, /* 01110110 */
   0xdc, /* 11011100 */
   0x00, /* 00000000 */
   0xe6, /* 11100110 */
   0xf6, /* 11110110 */
   0xde, /* 11011110 */
   0xce, /* 11001110 */
   0x00, /* 00000000 */

   /* 166 0xa6 '' */
   0x3c, /* 00111100 */
   0x6c, /* 01101100 */
   0x6c, /* 01101100 */
   0x3e, /* 00111110 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 167 0xa7 '' */
   0x38, /* 00111000 */
   0x6c, /* 01101100 */
   0x6c, /* 01101100 */
   0x38, /* 00111000 */
   0x00, /* 00000000 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 168 0xa8 '' */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x63, /* 01100011 */
   0x3e, /* 00111110 */
   0x00, /* 00000000 */

   /* 169 0xa9 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xfe, /* 11111110 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 170 0xaa '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xfe, /* 11111110 */
   0x06, /* 00000110 */
   0x06, /* 00000110 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 171 0xab '' */
   0x63, /* 01100011 */
   0xe6, /* 11100110 */
   0x6c, /* 01101100 */
   0x7e, /* 01111110 */
   0x33, /* 00110011 */
   0x66, /* 01100110 */
   0xcc, /* 11001100 */
   0x0f, /* 00001111 */

   /* 172 0xac '' */
   0x63, /* 01100011 */
   0xe6, /* 11100110 */
   0x6c, /* 01101100 */
   0x7a, /* 01111010 */
   0x36, /* 00110110 */
   0x6a, /* 01101010 */
   0xdf, /* 11011111 */
   0x06, /* 00000110 */

   /* 173 0xad '' */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x3c, /* 00111100 */
   0x3c, /* 00111100 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 174 0xae '' */
   0x00, /* 00000000 */
   0x33, /* 00110011 */
   0x66, /* 01100110 */
   0xcc, /* 11001100 */
   0x66, /* 01100110 */
   0x33, /* 00110011 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 175 0xaf '' */
   0x00, /* 00000000 */
   0xcc, /* 11001100 */
   0x66, /* 01100110 */
   0x33, /* 00110011 */
   0x66, /* 01100110 */
   0xcc, /* 11001100 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 176 0xb0 '' */
   0x22, /* 00100010 */
   0x88, /* 10001000 */
   0x22, /* 00100010 */
   0x88, /* 10001000 */
   0x22, /* 00100010 */
   0x88, /* 10001000 */
   0x22, /* 00100010 */
   0x88, /* 10001000 */

   /* 177 0xb1 '' */
   0x55, /* 01010101 */
   0xaa, /* 10101010 */
   0x55, /* 01010101 */
   0xaa, /* 10101010 */
   0x55, /* 01010101 */
   0xaa, /* 10101010 */
   0x55, /* 01010101 */
   0xaa, /* 10101010 */

   /* 178 0xb2 '' */
   0x77, /* 01110111 */
   0xdd, /* 11011101 */
   0x77, /* 01110111 */
   0xdd, /* 11011101 */
   0x77, /* 01110111 */
   0xdd, /* 11011101 */
   0x77, /* 01110111 */
   0xdd, /* 11011101 */

   /* 179 0xb3 '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 180 0xb4 '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0xf8, /* 11111000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 181 0xb5 '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0xf8, /* 11111000 */
   0x18, /* 00011000 */
   0xf8, /* 11111000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 182 0xb6 '' */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0xf6, /* 11110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */

   /* 183 0xb7 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xfe, /* 11111110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */

   /* 184 0xb8 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xf8, /* 11111000 */
   0x18, /* 00011000 */
   0xf8, /* 11111000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 185 0xb9 '' */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0xf6, /* 11110110 */
   0x06, /* 00000110 */
   0xf6, /* 11110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */

   /* 186 0xba '' */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */

   /* 187 0xbb '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xfe, /* 11111110 */
   0x06, /* 00000110 */
   0xf6, /* 11110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */

   /* 188 0xbc '' */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0xf6, /* 11110110 */
   0x06, /* 00000110 */
   0xfe, /* 11111110 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 189 0xbd '' */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0xfe, /* 11111110 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 190 0xbe '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0xf8, /* 11111000 */
   0x18, /* 00011000 */
   0xf8, /* 11111000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 191 0xbf '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xf8, /* 11111000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 192 0xc0 '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x1f, /* 00011111 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 193 0xc1 '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0xff, /* 11111111 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 194 0xc2 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xff, /* 11111111 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 195 0xc3 '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x1f, /* 00011111 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 196 0xc4 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xff, /* 11111111 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 197 0xc5 '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0xff, /* 11111111 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 198 0xc6 '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x1f, /* 00011111 */
   0x18, /* 00011000 */
   0x1f, /* 00011111 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 199 0xc7 '' */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x37, /* 00110111 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */

   /* 200 0xc8 '' */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x37, /* 00110111 */
   0x30, /* 00110000 */
   0x3f, /* 00111111 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 201 0xc9 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x3f, /* 00111111 */
   0x30, /* 00110000 */
   0x37, /* 00110111 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */

   /* 202 0xca '' */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0xf7, /* 11110111 */
   0x00, /* 00000000 */
   0xff, /* 11111111 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 203 0xcb '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xff, /* 11111111 */
   0x00, /* 00000000 */
   0xf7, /* 11110111 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */

   /* 204 0xcc '' */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x37, /* 00110111 */
   0x30, /* 00110000 */
   0x37, /* 00110111 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */

   /* 205 0xcd '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xff, /* 11111111 */
   0x00, /* 00000000 */
   0xff, /* 11111111 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 206 0xce '' */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0xf7, /* 11110111 */
   0x00, /* 00000000 */
   0xf7, /* 11110111 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */

   /* 207 0xcf '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0xff, /* 11111111 */
   0x00, /* 00000000 */
   0xff, /* 11111111 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 208 0xd0 '' */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0xff, /* 11111111 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 209 0xd1 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xff, /* 11111111 */
   0x00, /* 00000000 */
   0xff, /* 11111111 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 210 0xd2 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xff, /* 11111111 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */

   /* 211 0xd3 '' */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x3f, /* 00111111 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 212 0xd4 '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x1f, /* 00011111 */
   0x18, /* 00011000 */
   0x1f, /* 00011111 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 213 0xd5 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x1f, /* 00011111 */
   0x18, /* 00011000 */
   0x1f, /* 00011111 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 214 0xd6 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x3f, /* 00111111 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */

   /* 215 0xd7 '' */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0xff, /* 11111111 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */

   /* 216 0xd8 '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0xff, /* 11111111 */
   0x18, /* 00011000 */
   0xff, /* 11111111 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 217 0xd9 '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0xf8, /* 11111000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 218 0xda '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x1f, /* 00011111 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 219 0xdb '' */
   0xff, /* 11111111 */
   0xff, /* 11111111 */
   0xff, /* 11111111 */
   0xff, /* 11111111 */
   0xff, /* 11111111 */
   0xff, /* 11111111 */
   0xff, /* 11111111 */
   0xff, /* 11111111 */

   /* 220 0xdc '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xff, /* 11111111 */
   0xff, /* 11111111 */
   0xff, /* 11111111 */
   0xff, /* 11111111 */

   /* 221 0xdd '' */
   0xf0, /* 11110000 */
   0xf0, /* 11110000 */
   0xf0, /* 11110000 */
   0xf0, /* 11110000 */
   0xf0, /* 11110000 */
   0xf0, /* 11110000 */
   0xf0, /* 11110000 */
   0xf0, /* 11110000 */

   /* 222 0xde '' */
   0x0f, /* 00001111 */
   0x0f, /* 00001111 */
   0x0f, /* 00001111 */
   0x0f, /* 00001111 */
   0x0f, /* 00001111 */
   0x0f, /* 00001111 */
   0x0f, /* 00001111 */
   0x0f, /* 00001111 */

   /* 223 0xdf '' */
   0xff, /* 11111111 */
   0xff, /* 11111111 */
   0xff, /* 11111111 */
   0xff, /* 11111111 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 224 0xe0 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x76, /* 01110110 */
   0xdc, /* 11011100 */
   0xc8, /* 11001000 */
   0xdc, /* 11011100 */
   0x76, /* 01110110 */
   0x00, /* 00000000 */

   /* 225 0xe1 '' */
   0x78, /* 01111000 */
   0xcc, /* 11001100 */
   0xcc, /* 11001100 */
   0xd8, /* 11011000 */
   0xcc, /* 11001100 */
   0xc6, /* 11000110 */
   0xcc, /* 11001100 */
   0x00, /* 00000000 */

   /* 226 0xe2 '' */
   0xfe, /* 11111110 */
   0xc6, /* 11000110 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0xc0, /* 11000000 */
   0x00, /* 00000000 */

   /* 227 0xe3 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0xfe, /* 11111110 */
   0x6c, /* 01101100 */
   0x6c, /* 01101100 */
   0x6c, /* 01101100 */
   0x6c, /* 01101100 */
   0x00, /* 00000000 */

   /* 228 0xe4 '' */
   0xfe, /* 11111110 */
   0xc6, /* 11000110 */
   0x60, /* 01100000 */
   0x30, /* 00110000 */
   0x60, /* 01100000 */
   0xc6, /* 11000110 */
   0xfe, /* 11111110 */
   0x00, /* 00000000 */

   /* 229 0xe5 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0xd8, /* 11011000 */
   0xd8, /* 11011000 */
   0xd8, /* 11011000 */
   0x70, /* 01110000 */
   0x00, /* 00000000 */

   /* 230 0xe6 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x7c, /* 01111100 */
   0xc0, /* 11000000 */

   /* 231 0xe7 '' */
   0x00, /* 00000000 */
   0x76, /* 01110110 */
   0xdc, /* 11011100 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */

   /* 232 0xe8 '' */
   0x7e, /* 01111110 */
   0x18, /* 00011000 */
   0x3c, /* 00111100 */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x3c, /* 00111100 */
   0x18, /* 00011000 */
   0x7e, /* 01111110 */

   /* 233 0xe9 '' */
   0x38, /* 00111000 */
   0x6c, /* 01101100 */
   0xc6, /* 11000110 */
   0xfe, /* 11111110 */
   0xc6, /* 11000110 */
   0x6c, /* 01101100 */
   0x38, /* 00111000 */
   0x00, /* 00000000 */

   /* 234 0xea '' */
   0x38, /* 00111000 */
   0x6c, /* 01101100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x6c, /* 01101100 */
   0x6c, /* 01101100 */
   0xee, /* 11101110 */
   0x00, /* 00000000 */

   /* 235 0xeb '' */
   0x0e, /* 00001110 */
   0x18, /* 00011000 */
   0x0c, /* 00001100 */
   0x3e, /* 00111110 */
   0x66, /* 01100110 */
   0x66, /* 01100110 */
   0x3c, /* 00111100 */
   0x00, /* 00000000 */

   /* 236 0xec '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0xdb, /* 11011011 */
   0xdb, /* 11011011 */
   0x7e, /* 01111110 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 237 0xed '' */
   0x06, /* 00000110 */
   0x0c, /* 00001100 */
   0x7e, /* 01111110 */
   0xdb, /* 11011011 */
   0xdb, /* 11011011 */
   0x7e, /* 01111110 */
   0x60, /* 01100000 */
   0xc0, /* 11000000 */

   /* 238 0xee '' */
   0x1e, /* 00011110 */
   0x30, /* 00110000 */
   0x60, /* 01100000 */
   0x7e, /* 01111110 */
   0x60, /* 01100000 */
   0x30, /* 00110000 */
   0x1e, /* 00011110 */
   0x00, /* 00000000 */

   /* 239 0xef '' */
   0x00, /* 00000000 */
   0x7c, /* 01111100 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0xc6, /* 11000110 */
   0x00, /* 00000000 */

   /* 240 0xf0 '' */
   0x00, /* 00000000 */
   0xfe, /* 11111110 */
   0x00, /* 00000000 */
   0xfe, /* 11111110 */
   0x00, /* 00000000 */
   0xfe, /* 11111110 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 241 0xf1 '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x7e, /* 01111110 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0x00, /* 00000000 */

   /* 242 0xf2 '' */
   0x30, /* 00110000 */
   0x18, /* 00011000 */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0x00, /* 00000000 */

   /* 243 0xf3 '' */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x18, /* 00011000 */
   0x0c, /* 00001100 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0x00, /* 00000000 */

   /* 244 0xf4 '' */
   0x0e, /* 00001110 */
   0x1b, /* 00011011 */
   0x1b, /* 00011011 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */

   /* 245 0xf5 '' */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0xd8, /* 11011000 */
   0xd8, /* 11011000 */
   0x70, /* 01110000 */

   /* 246 0xf6 '' */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x7e, /* 01111110 */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 247 0xf7 '' */
   0x00, /* 00000000 */
   0x76, /* 01110110 */
   0xdc, /* 11011100 */
   0x00, /* 00000000 */
   0x76, /* 01110110 */
   0xdc, /* 11011100 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 248 0xf8 '' */
   0x38, /* 00111000 */
   0x6c, /* 01101100 */
   0x6c, /* 01101100 */
   0x38, /* 00111000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 249 0xf9 '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 250 0xfa '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x18, /* 00011000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 251 0xfb '' */
   0x0f, /* 00001111 */
   0x0c, /* 00001100 */
   0x0c, /* 00001100 */
   0x0c, /* 00001100 */
   0xec, /* 11101100 */
   0x6c, /* 01101100 */
   0x3c, /* 00111100 */
   0x1c, /* 00011100 */

   /* 252 0xfc '' */
   0x6c, /* 01101100 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x36, /* 00110110 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 253 0xfd '' */
   0x78, /* 01111000 */
   0x0c, /* 00001100 */
   0x18, /* 00011000 */
   0x30, /* 00110000 */
   0x7c, /* 01111100 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 254 0xfe '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x3c, /* 00111100 */
   0x3c, /* 00111100 */
   0x3c, /* 00111100 */
   0x3c, /* 00111100 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

   /* 255 0xff '' */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */
   0x00, /* 00000000 */

};
int x,y;
unsigned char buffer[256];

	LCD_cursor(0xF000);										// address "CGROM" (actually RAM mapped at that address)
	LCD_WriteCmd(0x42);										// MWRITE
	for(y=0;y<8;y++){
		xmem2root(&buffer,(long) fontdata+256*y,256);
																	// read data from xmem
		for(x=0;x<256;x++)
			LCD_Write(buffer[x]);							// send data to display
	}
}


/* RTC functions */

void get_datetime()
{
struct tm thetm;

	mktm(&thetm, SEC_TIMER);
	sprintf(date,"%02d/%02d/%04d",thetm.tm_mday,thetm.tm_mon,1900+thetm.tm_year);
	sprintf(time,"%02d:%02d:%02d",thetm.tm_hour, thetm.tm_min, thetm.tm_sec);
}

#define MAX_FORMSIZE	64
typedef struct {
	char *name;
	char value[MAX_FORMSIZE];
} FORMType;
FORMType FORMSpec[1];

/*
 * Parse one token 'foo=bar', matching 'foo' to the name field in
 * the struct, and storing 'bar' into the value
 */
void parse_token(HttpState* state)
{
	auto int i, len;

	for(i=0; i<HTTP_MAXBUFFER; i++) {
		if(state->buffer[i] == '=')
			state->buffer[i] = '\0';
	}
	state->p = state->buffer + strlen(state->buffer) + 1;

	for(i=0; i<(sizeof(FORMSpec)/sizeof(FORMType)); i++) {
		if(!strcmp(FORMSpec[i].name,state->buffer)) {
			len = (strlen(state->p)>MAX_FORMSIZE) ? MAX_FORMSIZE - 1: strlen(state->p);
			strncpy(FORMSpec[i].value,state->p,1+len);
			FORMSpec[i].value[MAX_FORMSIZE - 1] = '\0';
		}
	}
}

/*
 * parse the url-encoded POST data into the FORMSpec struct
 * (ie: parse 'foo=bar&baz=qux' into the struct
 */
int parse_post(HttpState* state)
{
	auto int retval;

	while(1) {
		retval = sock_fastread(&state->s, state->p, 1);
		if(0 == retval) {
			*state->p = '\0';
			parse_token(state);

			return 1;
		}

		/* should this only be '&'? (allow the eoln as valid text?) */
		if((*state->p == '&') || (*state->p == '\r') || (*state->p == '\n')) {
			/* found one token */
			*state->p = '\0';
			parse_token(state);

			state->p = state->buffer;
		} else {
			state->p++;
		}

		if((state->p - state->buffer) > HTTP_MAXBUFFER) {
			/* input too long */
			return 1;
		}
	}

	return 0; /* end of data - loop again to give it time to write more */
}


int submit(HttpState* state)
{
char buffer[MAX_FORMSIZE];
char num[5];

	FORMSpec[0].value[0] = 0;									// init form data
	if(parse_post(state)) {
		if(*(http_urldecode(buffer,FORMSpec[0].value,MAX_FORMSIZE))) { // decode data, ignore empty strings
			buffer[36]=0;											// cut string to display limits
			LCD_scroll();											// move up past messages
			if (msg==99)
				msg=0;
			sprintf(num,"%2d: ",msg);
			LCD_printat(29,0,num);								// show current msg#
			LCD_printat(29,4,buffer);							// show current msg
			msg++;													// update msg counter
		}
		cgi_redirectto(state,REDIRECTTO);					// Show OK screen
	} else {
									// insert error handling here
	}
	return(0);
}



/* MAIN PROGRAM */

main()
{
int i;

	msg=1;
	FORMSpec[0].name = "texto";

   sock_init();
   http_init();

	LCD_init();
	LCD_cleartxt();
	LCD_cleargfx();
	LCD_loadfont();

	while (1) {										// endless loop

		costate {
	      http_handler();						// TCP/IP stuff
			yield;									// pass execution on to next costatement
		}

		costate {
			waitfor(DelaySec(1));				// waits until 1 second have passed
			get_datetime();						// update date & time strings
			LCD_printat(0,10,date);
			LCD_printat(0,22,time);
		}
	}
}

